<?php

namespace Drupal\simple_survey\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\simple_survey\Entity\SimpleSurveyInterface;

/**
 * Defines the SimpleSurvey entity.
 *
 * @ConfigEntityType(
 *   id = "simple_survey",
 *   label = @Translation("Simple feedback survey"),
 *   label_collection = @Translation("Simple feedback surveys"),
 *   label_singular = @Translation("Simple feedback survey"),
 *   label_plural = @Translation("Simple feedback surveys"),
 *   label_count = @PluralTranslation(
 *     singular = "@count Simple feedback survey",
 *     plural = "@count Simple feedback surveys",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\simple_survey\Controller\SimpleSurveyListBuilder",
 *     "form" = {
 *       "add" = "Drupal\simple_survey\Form\SimpleSurveyForm",
 *       "edit" = "Drupal\simple_survey\Form\SimpleSurveyForm",
 *       "delete" = "Drupal\simple_survey\Form\SimpleSurveyDeleteForm"
 *     },
 *   },
 *   config_prefix = "simple_survey",
 *   admin_permission = "administer simple survey configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "debug",
 *     "description",
 *     "basePath",
 *     "questionsPath",
 *     "submitPath",
 *     "validationPath",
 *     "enableTranslation",
 *     "anchorTag",
 *     "attachStylesheet",
 *     "displayDelayType",
 *     "delay",
 *     "delayPosition",
 *     "displayOnceOnSite",
 *     "closingDelay",
 *     "bigQueryProjectId",
 *     "bigQueryKeyfile",
 *     "bigQueryTable",
 *     "questionWeights",
 *     "useFontAwesome"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/system/simple_survey/{simple_survey}",
 *     "add-form" = "/admin/config/system/simple_survey/{simple_survey}/add",
 *     "edit-form" = "/admin/config/system/simple_survey/{simple_survey}/edit",
 *     "delete-form" = "/admin/config/system/simple_survey/{simple_survey}/delete",
 *     "collection" = "/admin/config/system/simple_survey",
 *   }
 * )
 */
class SimpleSurvey extends ConfigEntityBase implements SimpleSurveyInterface {

  /**
   * Survey in debug mode.
   *
   * @var bool
   */
  public $debug;

  /**
   * Survey Base Path.
   *
   * @var string
   */
  public $basePath;

  /**
   * Survey Question Path.
   *
   * @var string
   */
  public $questionsPath;

  /**
   * Survey Submission Path.
   *
   * @var string
   */
  public $submitPath;

  /**
   * Survey validation Path.
   *
   * @var string
   */
  public $validationPath;

  /**
   * Enable Translation.
   *
   * @var bool
   */
  public $enableTranslation;

  /**
   * The SimpleSurvey ID.
   *
   * @var string
   */
  public $id;

  /**
   * The SimpleSurvey label.
   *
   * @var string
   */
  public $label;

  /**
   * A brief description of this simple feedback survey.
   *
   * @var string
   */
  public $description;

  /**
   * HTML tag or ID Survey should anchor to.
   *
   * @var string
   */
  public $anchorTag;

  /**
   * Attach module stylesheet.
   *
   * @var bool
   */
  public $attachStylesheet;

  /**
   * How should the survey display.
   *
   * @var string
   */
  public $displayDelayType;

  /**
   * How long before the survey should appear.
   *
   * @var int
   */
  public $delay;

  /**
   * Only display once on the entire site.
   *
   * @var bool
   */
  public $displayOnceOnSite;

  /**
   * Amount of time before survey closes on last screen.
   *
   * @var int
   */
  public $closingDelay;

  /**
   * If using positional delay where should it appear.
   *
   * @var string
   */
  public $delayPosition;

  /**
   * Use font awesome if it is available.
   *
   * @var bool
   */
  public $useFontAwesome;

  /**
   * Project ID in BigQuery.
   *
   * @var string
   */
  public $bigQueryProjectId;

  /**
   * BigQuery key file text.
   *
   * @var string
   */
  public $bigQueryKeyfile;

  /**
   * Table used in BigQuery.
   *
   * @var bool
   */
  public $bigQueryTable;

  /**
   * Question weights.
   *
   * @var array
   */
  public $questionWeights;

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * {@inheritdoc}
   */
  public function getDebug() {
    return $this->debug;
  }

}
